"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prism_core_1 = __importDefault(require("./prism-core"));
require("./prism-clike");
require("./prism-javascript");
// Ignore comments starting with { to privilege string interpolation highlighting
var comment = /#(?!\{).+/, interpolation = {
    pattern: /#\{[^}]+\}/,
    alias: 'variable',
};
prism_core_1.default.languages.coffeescript = prism_core_1.default.languages.extend('javascript', {
    comment: comment,
    string: [
        // Strings are multiline
        {
            pattern: /'(?:\\[\s\S]|[^\\'])*'/,
            greedy: true,
        },
        {
            // Strings are multiline
            pattern: /"(?:\\[\s\S]|[^\\"])*"/,
            greedy: true,
            inside: {
                interpolation: interpolation,
            },
        },
    ],
    keyword: /\b(?:and|break|by|catch|class|continue|debugger|delete|do|each|else|extend|extends|false|finally|for|if|in|instanceof|is|isnt|let|loop|namespace|new|no|not|null|of|off|on|or|own|return|super|switch|then|this|throw|true|try|typeof|undefined|unless|until|when|while|window|with|yes|yield)\b/,
    'class-member': {
        pattern: /@(?!\d)\w+/,
        alias: 'variable',
    },
});
prism_core_1.default.languages.insertBefore('coffeescript', 'comment', {
    'multiline-comment': {
        pattern: /###[\s\S]+?###/,
        alias: 'comment',
    },
    // Block regexp can contain comments and interpolation
    'block-regex': {
        pattern: /\/{3}[\s\S]*?\/{3}/,
        alias: 'regex',
        inside: {
            comment: comment,
            interpolation: interpolation,
        },
    },
});
prism_core_1.default.languages.insertBefore('coffeescript', 'string', {
    'inline-javascript': {
        pattern: /`(?:\\[\s\S]|[^\\`])*`/,
        inside: {
            delimiter: {
                pattern: /^`|`$/,
                alias: 'punctuation',
            },
            script: {
                pattern: /[\s\S]+/,
                alias: 'language-javascript',
                inside: prism_core_1.default.languages.javascript,
            },
        },
    },
    // Block strings
    'multiline-string': [
        {
            pattern: /'''[\s\S]*?'''/,
            greedy: true,
            alias: 'string',
        },
        {
            pattern: /"""[\s\S]*?"""/,
            greedy: true,
            alias: 'string',
            inside: {
                interpolation: interpolation,
            },
        },
    ],
});
prism_core_1.default.languages.insertBefore('coffeescript', 'keyword', {
    // Object property
    property: /(?!\d)\w+(?=\s*:(?!:))/,
});
delete prism_core_1.default.languages.coffeescript['template-string'];
prism_core_1.default.languages.coffee = prism_core_1.default.languages.coffeescript;
