"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prism_core_1 = __importDefault(require("./prism-core"));
require("./prism-markup");
require("./prism-markup-templating");
// Django/Jinja2 syntax definition for Prism.js <http://prismjs.com> syntax highlighter.
// Mostly it works OK but can paint code incorrectly on complex html/template tag combinations.
prism_core_1.default.languages.django = {
    comment: /^{#[\s\S]*?#}$/,
    tag: {
        pattern: /(^{%[+-]?\s*)\w+/,
        lookbehind: true,
        alias: 'keyword',
    },
    delimiter: {
        pattern: /^{[{%][+-]?|[+-]?[}%]}$/,
        alias: 'punctuation',
    },
    string: {
        pattern: /("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,
        greedy: true,
    },
    filter: {
        pattern: /(\|)\w+/,
        lookbehind: true,
        alias: 'function',
    },
    test: {
        pattern: /(\bis\s+(?:not\s+)?)(?!not\b)\w+/,
        lookbehind: true,
        alias: 'function',
    },
    function: /\b[a-z_]\w+(?=\s*\()/i,
    keyword: /\b(?:and|as|by|else|for|if|import|in|is|loop|not|or|recursive|with|without)\b/,
    operator: /[-+*/%=]=?|!=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,
    number: /\b\d+(?:\.\d+)?\b/,
    boolean: /[Tt]rue|[Ff]alse|[Nn]one/,
    variable: /\b\w+?\b/,
    punctuation: /[{}[\](),.:;]/,
};
var pattern = /{{[\s\S]*?}}|{%[\s\S]*?%}|{#[\s\S]*?#}/g;
var markupTemplating = prism_core_1.default.languages['markup-templating'];
prism_core_1.default.hooks.add('before-tokenize', function (env) {
    markupTemplating.buildPlaceholders(env, 'django', pattern);
});
prism_core_1.default.hooks.add('after-tokenize', function (env) {
    markupTemplating.tokenizePlaceholders(env, 'django');
});
// Add an Jinja2 alias
prism_core_1.default.languages.jinja2 = prism_core_1.default.languages.django;
prism_core_1.default.hooks.add('before-tokenize', function (env) {
    markupTemplating.buildPlaceholders(env, 'jinja2', pattern);
});
prism_core_1.default.hooks.add('after-tokenize', function (env) {
    markupTemplating.tokenizePlaceholders(env, 'jinja2');
});
