"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prism_core_1 = __importDefault(require("./prism-core"));
prism_core_1.default.languages.elixir = {
    comment: /#.*/m,
    // ~r"""foo""" (multi-line), ~r'''foo''' (multi-line), ~r/foo/, ~r|foo|, ~r"foo", ~r'foo', ~r(foo), ~r[foo], ~r{foo}, ~r<foo>
    regex: {
        pattern: /~[rR](?:("""|''')(?:\\[\s\S]|(?!\1)[^\\])+\1|([\/|"'])(?:\\.|(?!\2)[^\\\r\n])+\2|\((?:\\.|[^\\)\r\n])+\)|\[(?:\\.|[^\\\]\r\n])+\]|\{(?:\\.|[^\\}\r\n])+\}|<(?:\\.|[^\\>\r\n])+>)[uismxfr]*/,
        greedy: true,
    },
    string: [
        {
            // ~s"""foo""" (multi-line), ~s'''foo''' (multi-line), ~s/foo/, ~s|foo|, ~s"foo", ~s'foo', ~s(foo), ~s[foo], ~s{foo} (with interpolation care), ~s<foo>
            pattern: /~[cCsSwW](?:("""|''')(?:\\[\s\S]|(?!\1)[^\\])+\1|([\/|"'])(?:\\.|(?!\2)[^\\\r\n])+\2|\((?:\\.|[^\\)\r\n])+\)|\[(?:\\.|[^\\\]\r\n])+\]|\{(?:\\.|#\{[^}]+\}|#(?!\{)|[^#\\}\r\n])+\}|<(?:\\.|[^\\>\r\n])+>)[csa]?/,
            greedy: true,
            inside: {
            // See interpolation below
            },
        },
        {
            pattern: /("""|''')[\s\S]*?\1/,
            greedy: true,
            inside: {
            // See interpolation below
            },
        },
        {
            // Multi-line strings are allowed
            pattern: /("|')(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,
            greedy: true,
            inside: {
            // See interpolation below
            },
        },
    ],
    atom: {
        // Look-behind prevents bad highlighting of the :: operator
        pattern: /(^|[^:]):\w+/,
        lookbehind: true,
        alias: 'symbol',
    },
    // Look-ahead prevents bad highlighting of the :: operator
    'attr-name': /\w+\??:(?!:)/,
    capture: {
        // Look-behind prevents bad highlighting of the && operator
        pattern: /(^|[^&])&(?:[^&\s\d()][^\s()]*|(?=\())/,
        lookbehind: true,
        alias: 'function',
    },
    argument: {
        // Look-behind prevents bad highlighting of the && operator
        pattern: /(^|[^&])&\d+/,
        lookbehind: true,
        alias: 'variable',
    },
    attribute: {
        pattern: /@\w+/,
        alias: 'variable',
    },
    number: /\b(?:0[box][a-f\d_]+|\d[\d_]*)(?:\.[\d_]+)?(?:e[+-]?[\d_]+)?\b/i,
    keyword: /\b(?:after|alias|and|case|catch|cond|def(?:callback|exception|impl|module|p|protocol|struct|delegate)?|do|else|end|fn|for|if|import|not|or|require|rescue|try|unless|use|when)\b/,
    boolean: /\b(?:true|false|nil)\b/,
    operator: [
        /\bin\b|&&?|\|[|>]?|\\\\|::|\.\.\.?|\+\+?|-[->]?|<[-=>]|>=|!==?|\B!|=(?:==?|[>~])?|[*\/^]/,
        {
            // We don't want to match <<
            pattern: /([^<])<(?!<)/,
            lookbehind: true,
        },
        {
            // We don't want to match >>
            pattern: /([^>])>(?!>)/,
            lookbehind: true,
        },
    ],
    punctuation: /<<|>>|[.,%\[\]{}()]/,
};
prism_core_1.default.languages.insertBefore('elixir', 'keyword', {
    module: {
        pattern: /\b(defmodule\s)[A-Z][\w.\\]+/,
        lookbehind: true,
        alias: 'class-name',
    },
    function: {
        pattern: /\b(defp?\s)[\w.\\]+/,
        lookbehind: true,
    },
});
prism_core_1.default.languages.elixir.string.forEach(function (o) {
    o.inside = {
        interpolation: {
            pattern: /#\{[^}]+\}/,
            inside: {
                delimiter: {
                    pattern: /^#\{|\}$/,
                    alias: 'punctuation',
                },
                rest: prism_core_1.default.languages.elixir,
            },
        },
    };
});
