"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prism_core_1 = __importDefault(require("./prism-core"));
require("./prism-clike");
/**
 * Original by Samuel Flores
 *
 * Adds the following new token classes:
 *     constant, builtin, variable, symbol, regex
 */
prism_core_1.default.languages.ruby = prism_core_1.default.languages.extend('clike', {
    comment: [
        /#.*/,
        {
            pattern: /^=begin\s[\s\S]*?^=end/m,
            greedy: true,
        },
    ],
    'class-name': {
        pattern: /(\b(?:class)\s+|\bcatch\s+\()[\w.\\]+/i,
        lookbehind: true,
        inside: {
            punctuation: /[.\\]/,
        },
    },
    keyword: /\b(?:alias|and|BEGIN|begin|break|case|class|def|define_method|defined|do|each|else|elsif|END|end|ensure|extend|for|if|in|include|module|new|next|nil|not|or|prepend|protected|private|public|raise|redo|require|rescue|retry|return|self|super|then|throw|undef|unless|until|when|while|yield)\b/,
});
var interpolation = {
    pattern: /#\{[^}]+\}/,
    inside: {
        delimiter: {
            pattern: /^#\{|\}$/,
            alias: 'tag',
        },
        rest: prism_core_1.default.languages.ruby,
    },
};
delete prism_core_1.default.languages.ruby.function;
prism_core_1.default.languages.insertBefore('ruby', 'keyword', {
    regex: [
        {
            pattern: RegExp(/%r/.source +
                '(?:' +
                [
                    /([^a-zA-Z0-9\s{(\[<])(?:(?!\1)[^\\]|\\[\s\S])*\1[gim]{0,3}/.source,
                    /\((?:[^()\\]|\\[\s\S])*\)[gim]{0,3}/.source,
                    // Here we need to specifically allow interpolation
                    /\{(?:[^#{}\\]|#(?:\{[^}]+\})?|\\[\s\S])*\}[gim]{0,3}/.source,
                    /\[(?:[^\[\]\\]|\\[\s\S])*\][gim]{0,3}/.source,
                    /<(?:[^<>\\]|\\[\s\S])*>[gim]{0,3}/.source,
                ].join('|') +
                ')'),
            greedy: true,
            inside: {
                interpolation: interpolation,
            },
        },
        {
            pattern: /(^|[^/])\/(?!\/)(?:\[[^\r\n\]]+\]|\\.|[^[/\\\r\n])+\/[gim]{0,3}(?=\s*(?:$|[\r\n,.;})]))/,
            lookbehind: true,
            greedy: true,
        },
    ],
    variable: /[@$]+[a-zA-Z_]\w*(?:[?!]|\b)/,
    symbol: {
        pattern: /(^|[^:]):[a-zA-Z_]\w*(?:[?!]|\b)/,
        lookbehind: true,
    },
    'method-definition': {
        pattern: /(\bdef\s+)[\w.]+/,
        lookbehind: true,
        inside: {
            function: /\w+$/,
            rest: prism_core_1.default.languages.ruby,
        },
    },
});
prism_core_1.default.languages.insertBefore('ruby', 'number', {
    builtin: /\b(?:Array|Bignum|Binding|Class|Continuation|Dir|Exception|FalseClass|File|Stat|Fixnum|Float|Hash|Integer|IO|MatchData|Method|Module|NilClass|Numeric|Object|Proc|Range|Regexp|String|Struct|TMS|Symbol|ThreadGroup|Thread|Time|TrueClass)\b/,
    constant: /\b[A-Z]\w*(?:[?!]|\b)/,
});
prism_core_1.default.languages.ruby.string = [
    {
        pattern: RegExp(/%[qQiIwWxs]?/.source +
            '(?:' +
            [
                /([^a-zA-Z0-9\s{(\[<])(?:(?!\1)[^\\]|\\[\s\S])*\1/.source,
                /\((?:[^()\\]|\\[\s\S])*\)/.source,
                // Here we need to specifically allow interpolation
                /\{(?:[^#{}\\]|#(?:\{[^}]+\})?|\\[\s\S])*\}/.source,
                /\[(?:[^\[\]\\]|\\[\s\S])*\]/.source,
                /<(?:[^<>\\]|\\[\s\S])*>/.source,
            ].join('|') +
            ')'),
        greedy: true,
        inside: {
            interpolation: interpolation,
        },
    },
    {
        pattern: /("|')(?:#\{[^}]+\}|#(?!\{)|\\(?:\r\n|[\s\S])|(?!\1)[^\\#\r\n])*\1/,
        greedy: true,
        inside: {
            interpolation: interpolation,
        },
    },
];
prism_core_1.default.languages.rb = prism_core_1.default.languages.ruby;
